%
%  combineMatrices.m
%  Copyright (C) 2018 Frederick Sander, Heiner Zille, Sanaz Mostaghim
%
%  This program is free software: you can redistribute it and/or modify
%  it under the terms of the GNU General Public License as published by
%  the Free Software Foundation, either version 3 of the License, or
%  (at your option) any later version.
%
%  This program is distributed in the hope that it will be useful,
%  but WITHOUT ANY WARRANTY; without even the implied warranty of
%  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%  GNU General Public License for more details.
%
%  You should have received a copy of the GNU General Public License
%  along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%  Authors of this Code: 
%   Frederick Sander <frederick.sander@posteo.de>
%   Heiner Zille <heiner.zille@ovgu.de>
%   Sanaz Mostaghim <sanaz.mostaghim@ovgu.de> 
%
%  This class belongs to the following publication:
%
%  Frederick Sander, Heiner Zille and Sanaz Mostaghim 
%  "Transfer strategies from single- to multi-objective grouping mechanisms"
%  Genetic and Evolutionary Computation Conference (GECCO), ACM, Kyoto, Japan, July 2018
%  https://dl.acm.org/citation.cfm?id=3205455.3205491
%


function combMat = combineMatrices(combinationFunction, intMat)
% the combination function should be all or any 
    dims    = length(intMat(:,:,1));
    combMat = false(length(intMat(:,:,1)));
    
    for ii = 1:dims
        for jj = (ii+1):dims
            if ii == jj
                combMat(jj, ii) = false;
            else 
                val = combinationFunction(intMat(ii, jj, :));
                combMat(jj, ii) = val;
                combMat(ii, jj) = val;
            end
        end
    end
end